##  Trigger Synchronization
Once the initial configuration is complete, you can trigger a manual synchronization run by clicking on the Trigger synchronization button. This allows you to verify your configuration and view results immediately. Additionally, you can manually trigger synchronization runs whenever you change configuration. Scheduled synchronization runs occur automatically every 4 hours.
You can view the result of the latest synchronization run in the Overview tab with the following possible statuses:
  * Synced: The latest run was completed successfully.
  * Error: There is an issue in the latest run, causing the synchronization to be aborted.
  * Disabled: There are no active mappings configured


To see more details on the status, click on Sync Log at the top.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
